<?php

namespace Hrm\Staffrate\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Staffrate\Models\Staffrate;

class StaffratePolicy
{

    /**
     * Determine if the given user can view the staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function view(UserPolicy $user, Staffrate $staffrate)
    {
        if ($user->canDo('staffrate.staffrate.view') && $user->isAdmin()) {
            return true;
        }

        return $staffrate->user_id == user_id() && $staffrate->user_type == user_type();
    }

    /**
     * Determine if the given user can create a staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('staffrate.staffrate.create');
    }

    /**
     * Determine if the given user can update the given staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function update(UserPolicy $user, Staffrate $staffrate)
    {
        if ($user->canDo('staffrate.staffrate.edit') && $user->isAdmin()) {
            return true;
        }

        return $staffrate->user_id == user_id() && $staffrate->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Staffrate $staffrate)
    {
        return $staffrate->user_id == user_id() && $staffrate->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Staffrate $staffrate)
    {
        if ($user->canDo('staffrate.staffrate.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given staffrate.
     *
     * @param UserPolicy $user
     * @param Staffrate $staffrate
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Staffrate $staffrate)
    {
        if ($user->canDo('staffrate.staffrate.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
