<?php

namespace Hrm\Staffrate\Providers;

use Illuminate\Support\ServiceProvider;

class StaffrateServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'staffrate');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'staffrate');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerStaffrate();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerStaffrate()
    {
        $this->app->bind('staffrate', function($app) {
            return new Staffrate($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Staffrate', 'Lavalite\Staffrate\Facades\Staffrate');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.staffrate', function ($app) {
            return $this->app->make('Hrm\Staffrate\Staffrate');
        });

                // Bind Staffrate to repository
        $this->app->bind(
            'Hrm\Staffrate\Interfaces\StaffrateRepositoryInterface',
            \Hrm\Staffrate\Repositories\Eloquent\StaffrateRepository::class
        );

        $this->app->register(\Hrm\Staffrate\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\Staffrate\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and staffrate's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/staffrate.php', 'staffrate'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeStaffrate::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.staffrate'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/staffrate.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/staffrate')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/staffrate')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
